@@ -1,5 +1,7 @@
+# vim: ts=8:sts=8:sw=8:noexpandtab
+
 # This file is part of ReText
-# Copyright: 2012-2014 Dmitry Shachnev
+# Copyright: 2012-2017 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import sys
 import markups
 import markups.common
 from os.path import dirname, exists, join
@@ -21,55 +24,61 @@ from os.path import dirname, exists, join
 from PyQt5.QtCore import QByteArray, QLocale, QSettings, QStandardPaths
 from PyQt5.QtGui import QFont
 
-app_version = "5.3.1"
+app_version = "7.0.0"
 
 settings = QSettings('ReText project', 'ReText')
-print('Using configuration file:', settings.fileName())
 
 if not str(settings.fileName()).endswith('.conf'):
 	# We are on Windows probably
 	settings = QSettings(QSettings.IniFormat, QSettings.UserScope,
 		'ReText project', 'ReText')
 
-try:
-	import enchant
-	import enchant.errors
-except ImportError:
-	enchant_available = False
-	enchant = None
-else:
-	enchant_available = True
-	try:
-		enchant.Dict()
-	except enchant.errors.Error:
-		enchant_available = False
+datadirs = []
 
-datadirs = QStandardPaths.standardLocations(QStandardPaths.GenericDataLocation)
-datadirs = [join(d, 'retext') for d in datadirs]
+def initializeDataDirs():
+	assert not datadirs
 
-if '__file__' in locals():
-	datadirs = [dirname(dirname(__file__))] + datadirs
+	if '__file__' in locals():
+		datadirs.append(dirname(dirname(__file__)))
 
-icon_path = 'icons/'
-for dir in datadirs:
-	if exists(join(dir, 'icons')):
-		icon_path = join(dir, 'icons/')
-		break
+	dataLocations = QStandardPaths.standardLocations(QStandardPaths.GenericDataLocation)
+	datadirs.extend(join(d, 'retext') for d in dataLocations)
+
+	if sys.platform == "win32":
+		# Windows compatibility: Add "PythonXXX\share\" path
+		datadirs.append(join(dirname(sys.executable), 'share', 'retext'))
+
+	# For virtualenvs
+	datadirs.append(join(dirname(dirname(sys.executable)), 'share', 'retext'))
+
+_iconPath = None
+
+def getBundledIcon(iconName):
+	global _iconPath
+	if _iconPath is None:
+		for dir in ['icons'] + datadirs:
+			_iconPath = join(dir, 'icons')
+			if exists(_iconPath):
+				break
+	return join(_iconPath, iconName + '.png')
 
 configOptions = {
 	'appStyleSheet': '',
 	'autoSave': False,
 	'defaultCodec': '',
-	'defaultMarkup': '',
-	'editorFont': QFont('monospace'),
+	'defaultMarkup': markups.MarkdownMarkup.name,
+	'detectEncoding': True,
+	'editorFont': QFont(),
 	'font': QFont(),
 	'handleWebLinks': False,
 	'hideToolBar': False,
 	'highlightCurrentLine': False,
 	'iconTheme': '',
+	'lastTabIndex': 0,
 	'lineNumbersEnabled': False,
 	'livePreviewByDefault': False,
 	'markdownDefaultFileExtension': '.mkd',
+	'openLastFilesOnStartup': False,
 	'pygmentsStyle': 'default',
 	'restDefaultFileExtension': '.rst',
 	'rightMargin': 0,
@@ -77,10 +86,13 @@ configOptions = {
 	'spellCheck': False,
 	'spellCheckLocale': '',
 	'styleSheet': '',
+	'syncScroll': True,
+	'tabBarAutoHide': False,
 	'tabInsertsSpaces': True,
 	'tabWidth': 4,
 	'uiLanguage': QLocale.system().name(),
 	'useFakeVim': False,
+	'useWebEngine': False,
 	'useWebKit': False,
 	'windowGeometry': QByteArray(),
 }
@@ -129,6 +141,11 @@ def writeListToSettings(key, value, settings=settings):
 	else:
 		settings.remove(key)
 
+def chooseMonospaceFont():
+	font = QFont('monospace')
+	font.setStyleHint(QFont.TypeWriter)
+	return font
+
 class ReTextSettings(object):
 	def __init__(self):
 		for option in configOptions:
@@ -142,6 +159,14 @@ class ReTextSettings(object):
 		object.__setattr__(self, option, value)
 		writeToSettings(option, value, configOptions[option])
 
+	def __getattribute__(self, option):
+		value = object.__getattribute__(self, option)
+		# Choose a font just-in-time, because when the settings are
+		# loaded it is too early to work on Windows
+		if option == 'editorFont' and not value.family():
+			value = chooseMonospaceFont()
+		return value
+
 globalSettings = ReTextSettings()
 
 markups.common.PYGMENTS_STYLE = globalSettings.pygmentsStyle
