@@ -1,7 +1,7 @@
 # vim: ts=8:sts=8:sw=8:noexpandtab
 #
 # This file is part of ReText
-# Copyright: 2012-2015 Dmitry Shachnev
+# Copyright: 2012-2017 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,9 +19,12 @@
 import markups
 import sys
 from subprocess import Popen
-from ReText import icon_path, app_version, globalSettings, readListFromSettings, \
- writeListToSettings, datadirs
-from ReText.tab import ReTextTab, ReTextWebPreview, PreviewNormal, PreviewLive
+import warnings
+
+from ReText import (getBundledIcon, app_version, globalSettings,
+                    readListFromSettings, writeListToSettings, datadirs)
+from ReText.tab import (ReTextTab, ReTextWebKitPreview, ReTextWebEnginePreview,
+                        PreviewNormal, PreviewLive)
 from ReText.dialogs import HtmlDialog, LocaleDialog
 from ReText.config import ConfigDialog
 from ReText.icontheme import get_icon_theme
@@ -60,14 +63,15 @@ class ReTextWindow(QMainWindow):
 			# https://github.com/retext-project/retext/issues/198
 			searchPaths = QIcon.themeSearchPaths()
 			searchPaths.append('/opt/local/share/icons')
+			searchPaths.append('/usr/local/share/icons')
 			QIcon.setThemeSearchPaths(searchPaths)
 		if globalSettings.iconTheme:
 			QIcon.setThemeName(globalSettings.iconTheme)
 		if QIcon.themeName() in ('hicolor', ''):
-			if not QFile.exists(icon_path + 'document-new.png'):
+			if not QFile.exists(getBundledIcon('document-new')):
 				QIcon.setThemeName(get_icon_theme())
-		if QFile.exists(icon_path+'retext.png'):
-			self.setWindowIcon(QIcon(icon_path+'retext.png'))
+		if QFile.exists(getBundledIcon('retext')):
+			self.setWindowIcon(QIcon(getBundledIcon('retext')))
 		elif QFile.exists('/usr/share/pixmaps/retext.png'):
 			self.setWindowIcon(QIcon('/usr/share/pixmaps/retext.png'))
 		else:
@@ -131,7 +135,7 @@ class ReTextWindow(QMainWindow):
 		elif QIcon.hasThemeIcon('x-office-document'):
 			self.actionPreview.setIcon(QIcon.fromTheme('x-office-document'))
 		else:
-			self.actionPreview.setIcon(QIcon(icon_path+'document-preview.png'))
+			self.actionPreview.setIcon(QIcon(getBundledIcon('document-preview')))
 		self.actionLivePreview = self.act(self.tr('Live preview'), shct=Qt.CTRL+Qt.Key_L,
 		trigbool=self.enableLivePreview)
 		menuPreview = QMenu()
@@ -180,15 +184,26 @@ class ReTextWindow(QMainWindow):
 			self.actionEnableSC = self.act(self.tr('Enable'), trigbool=self.enableSpellCheck)
 			self.actionSetLocale = self.act(self.tr('Set locale'), trig=self.changeLocale)
 		self.actionWebKit = self.act(self.tr('Use WebKit renderer'), trigbool=self.enableWebKit)
-		if ReTextWebPreview is None:
+		if ReTextWebKitPreview is None:
 			globalSettings.useWebKit = False
 			self.actionWebKit.setEnabled(False)
 		self.actionWebKit.setChecked(globalSettings.useWebKit)
+		self.actionWebEngine = self.act(self.tr('Use WebEngine (Chromium) renderer'),
+			trigbool=self.enableWebEngine)
+		if ReTextWebEnginePreview is None:
+			globalSettings.useWebEngine = False
+		self.actionWebEngine.setChecked(globalSettings.useWebEngine)
 		self.actionShow = self.act(self.tr('Show directory'), 'system-file-manager', self.showInDir)
 		self.actionFind = self.act(self.tr('Next'), 'go-next', self.find,
 			shct=QKeySequence.FindNext)
 		self.actionFindPrev = self.act(self.tr('Previous'), 'go-previous',
 			lambda: self.find(back=True), shct=QKeySequence.FindPrevious)
+		self.actionReplace = self.act(self.tr('Replace'), 'edit-find-replace',
+			lambda: self.find(replace=True))
+		self.actionReplaceAll = self.act(self.tr('Replace all'), trig=self.replaceAll)
+		menuReplace = QMenu()
+		menuReplace.addAction(self.actionReplaceAll)
+		self.actionReplace.setMenu(menuReplace)
 		self.actionCloseSearch = self.act(self.tr('Close'), 'window-close',
 			lambda: self.searchBar.setVisible(False))
 		self.actionCloseSearch.setPriority(QAction.LowPriority)
@@ -285,7 +300,10 @@ class ReTextWindow(QMainWindow):
 		menuFormat.addAction(self.actionBold)
 		menuFormat.addAction(self.actionItalic)
 		menuFormat.addAction(self.actionUnderline)
-		menuEdit.addAction(self.actionWebKit)
+		if ReTextWebKitPreview is not None or ReTextWebEnginePreview is None:
+			menuEdit.addAction(self.actionWebKit)
+		else:
+			menuEdit.addAction(self.actionWebEngine)
 		menuEdit.addSeparator()
 		menuEdit.addAction(self.actionViewHtml)
 		menuEdit.addAction(self.actionPreview)
@@ -320,12 +338,17 @@ class ReTextWindow(QMainWindow):
 		self.searchEdit = QLineEdit(self.searchBar)
 		self.searchEdit.setPlaceholderText(self.tr('Search'))
 		self.searchEdit.returnPressed.connect(self.find)
+		self.replaceEdit = QLineEdit(self.searchBar)
+		self.replaceEdit.setPlaceholderText(self.tr('Replace with'))
+		self.replaceEdit.returnPressed.connect(self.find)
 		self.csBox = QCheckBox(self.tr('Case sensitively'), self.searchBar)
 		self.searchBar.addWidget(self.searchEdit)
+		self.searchBar.addWidget(self.replaceEdit)
 		self.searchBar.addSeparator()
 		self.searchBar.addWidget(self.csBox)
 		self.searchBar.addAction(self.actionFindPrev)
 		self.searchBar.addAction(self.actionFind)
+		self.searchBar.addAction(self.actionReplace)
 		self.searchBar.addAction(self.actionCloseSearch)
 		self.searchBar.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
 		self.searchBar.setVisible(False)
@@ -340,13 +363,22 @@ class ReTextWindow(QMainWindow):
 			try:
 				enchant.Dict(self.sl or None)
 			except enchant.errors.Error as e:
-				print(e, file=sys.stderr)
+				warnings.warn(e, RuntimeWarning)
 				globalSettings.spellCheck = False
 			if globalSettings.spellCheck:
 				self.actionEnableSC.setChecked(True)
 		self.fileSystemWatcher = QFileSystemWatcher()
 		self.fileSystemWatcher.fileChanged.connect(self.fileChanged)
 
+	def restoreLastOpenedFiles(self):
+		for file in readListFromSettings("lastFileList"):
+			self.openFileWrapper(file)
+
+		# Show the tab of last opened file
+		lastTabIndex = globalSettings.lastTabIndex
+		if lastTabIndex >= 0 and lastTabIndex < self.tabWidget.count():
+			self.tabWidget.setCurrentIndex(lastTabIndex)
+
 	def iterateTabs(self):
 		for i in range(self.tabWidget.count()):
 			yield self.tabWidget.widget(i)
@@ -376,6 +408,8 @@ class ReTextWindow(QMainWindow):
 		self.tabWidget.setMovable(True)
 		self.tabWidget.dragEnterEvent = dragEnterEvent
 		self.tabWidget.dropEvent = dropEvent
+		if hasattr(self.tabWidget, 'setTabBarAutoHide'):
+			self.tabWidget.setTabBarAutoHide(globalSettings.tabBarAutoHide)
 
 	def act(self, name, icon=None, trig=None, trigbool=None, shct=None):
 		if not isinstance(shct, QKeySequence):
@@ -394,7 +428,7 @@ class ReTextWindow(QMainWindow):
 		return action
 
 	def actIcon(self, name):
-		return QIcon.fromTheme(name, QIcon(icon_path+name+'.png'))
+		return QIcon.fromTheme(name, QIcon(getBundledIcon(name)))
 
 	def printError(self):
 		import traceback
@@ -518,25 +552,26 @@ class ReTextWindow(QMainWindow):
 		self.actionLivePreview.setChecked(False)
 		self.editBar.setDisabled(viewmode)
 		self.currentTab.updateBoxesVisibility()
+		self.currentTab.triggerPreviewUpdate()
 
 	def enableLivePreview(self, livemode):
 		self.currentTab.previewState = int(livemode)
 		self.actionPreview.setChecked(livemode)
 		self.editBar.setEnabled(True)
 		self.currentTab.updateBoxesVisibility()
+		self.currentTab.triggerPreviewUpdate()
 
 	def enableWebKit(self, enable):
 		globalSettings.useWebKit = enable
+		globalSettings.useWebEngine = False
 		for tab in self.iterateTabs():
-			tab.previewBox.disconnectExternalSignals()
-			tab.previewBox.setParent(None)
-			tab.previewBox.deleteLater()
-			tab.previewBox = tab.createPreviewBox(tab.editBox)
-			tab.previewBox.setMinimumWidth(125)
-			tab.addWidget(tab.previewBox)
-			tab.setSizes((50, 50))
-			tab.triggerPreviewUpdate()
-			tab.updateBoxesVisibility()
+			tab.rebuildPreviewBox()
+
+	def enableWebEngine(self, enable):
+		globalSettings.useWebKit = False
+		globalSettings.useWebEngine = enable
+		for tab in self.iterateTabs():
+			tab.rebuildPreviewBox()
 
 	def enableCopy(self, copymode):
 		self.actionCopy.setEnabled(copymode)
@@ -558,7 +593,7 @@ class ReTextWindow(QMainWindow):
 		if yes:
 			FakeVimMode.init(self)
 			for tab in self.iterateTabs():
-				tab.installFakeVimHandler()
+				tab.editBox.installFakeVimHandler()
 		else:
 			FakeVimMode.exit(self)
 
@@ -598,14 +633,21 @@ class ReTextWindow(QMainWindow):
 		if visible:
 			self.searchEdit.setFocus(Qt.ShortcutFocusReason)
 
-	def find(self, back=False):
+	def find(self, back=False, replace=False):
 		flags = QTextDocument.FindFlags()
 		if back:
 			flags |= QTextDocument.FindBackward
 		if self.csBox.isChecked():
 			flags |= QTextDocument.FindCaseSensitively
 		text = self.searchEdit.text()
-		found = self.currentTab.find(text, flags)
+		replaceText = self.replaceEdit.text() if replace else None
+		found = self.currentTab.find(text, flags, replaceText=replaceText)
+		self.setSearchEditColor(found)
+
+	def replaceAll(self):
+		text = self.searchEdit.text()
+		replaceText = self.replaceEdit.text()
+		found = self.currentTab.replaceAll(text, replaceText)
 		self.setSearchEditColor(found)
 
 	def setSearchEditColor(self, found):
@@ -709,7 +751,7 @@ class ReTextWindow(QMainWindow):
 			if mimetype is None:
 				enabled = True
 			elif markupClass == markups.MarkdownMarkup:
-				enabled = (mimetype in ("text/x-retext-markdown", "text/x-markdown"))
+				enabled = (mimetype in ("text/x-retext-markdown", "text/x-markdown", "text/markdown"))
 			elif markupClass == markups.ReStructuredTextMarkup:
 				enabled = (mimetype in ("text/x-retext-rst", "text/x-rst"))
 			else:
@@ -735,7 +777,7 @@ class ReTextWindow(QMainWindow):
 			supportedExtensions += markup.file_extensions
 		fileFilter = ' (' + str.join(' ', ['*'+ext for ext in supportedExtensions]) + ');;'
 		fileNames = QFileDialog.getOpenFileNames(self,
-			self.tr("Select one or several files to open"), "",
+			self.tr("Select one or several files to open"), QDir.currentPath(),
 			self.tr("Supported files") + fileFilter + self.tr("All files (*)"))
 		for fileName in fileNames[0]:
 			self.openFileWrapper(fileName)
@@ -811,6 +853,12 @@ class ReTextWindow(QMainWindow):
 			if fileNameToSave:
 				if not QFileInfo(fileNameToSave).suffix():
 					fileNameToSave += ext
+				# Make sure we don't overwrite a file opened in other tab
+				for tab in self.iterateTabs():
+					if tab is not self.currentTab and tab.fileName == fileNameToSave:
+						QMessageBox.warning(self, "",
+							self.tr("Cannot save to file which is open in another tab!"))
+						return False
 				self.actionSetEncoding.setDisabled(self.autoSaveActive())
 		if fileNameToSave:
 			if self.currentTab.saveTextToFile(fileNameToSave):
@@ -830,7 +878,11 @@ class ReTextWindow(QMainWindow):
 		except Exception:
 			return self.printError()
 		htmlFile = QFile(fileName)
-		htmlFile.open(QIODevice.WriteOnly)
+		result = htmlFile.open(QIODevice.WriteOnly)
+		if not result:
+			QMessageBox.warning(self, '',
+				self.tr("Cannot save to file because it is read-only!"))
+			return
 		html = QTextStream(htmlFile)
 		if globalSettings.defaultCodec:
 			html.setCodec(globalSettings.defaultCodec)
@@ -1075,6 +1127,10 @@ class ReTextWindow(QMainWindow):
 				return closeevent.ignore()
 		if globalSettings.saveWindowGeometry and not self.isMaximized():
 			globalSettings.windowGeometry = self.saveGeometry()
+		if globalSettings.openLastFilesOnStartup:
+			files = [tab.fileName for tab in self.iterateTabs()]
+			writeListToSettings("lastFileList", files)
+			globalSettings.lastTabIndex = self.tabWidget.currentIndex()
 		closeevent.accept()
 
 	def viewHtml(self):
@@ -1100,7 +1156,7 @@ class ReTextWindow(QMainWindow):
 		'<p><b>' + (self.tr('ReText %s (using PyMarkups %s)') % (app_version, markups.__version__))
 		+'</b></p>' + self.tr('Simple but powerful editor'
 		' for Markdown and reStructuredText')
-		+'</p><p>'+self.tr('Author: Dmitry Shachnev, 2011').replace('2011', '2011–2016')
+		+'</p><p>'+self.tr('Author: Dmitry Shachnev, 2011').replace('2011', '2011–2017')
 		+'<br><a href="https://github.com/retext-project/retext">'+self.tr('Website')
 		+'</a> | <a href="http://daringfireball.net/projects/markdown/syntax">'
 		+self.tr('Markdown syntax')
